MidiSource

Trait MidiSource 

pub trait MidiSource {
    type Err;

    // Required methods
    fn tpq(&self) -> u32;
    fn next(&mut self) -> Result<Option<MidiEvent>, Self::Err>;
}
A pull-based stream of MidiEvents at a fixed resolution.

Required Associated Types

type Err

Error type returned by next.

Required Methods

fn tpq(&self) -> u32

Returns the source resolution in ticks per quarter note.

fn next(&mut self) -> Result<Option<MidiEvent>, Self::Err>

Returns the next event, or None once the stream is exhausted.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors